%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%         Non-equillibrium Green's function setup script
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

all_names = cell(length(Nw_all),1);

for i = 1 : length(Nw_all)
    mat.Nw = Nw_all(i);
    [mat] = material_selection(mat); %generate unit cell parameters

    %----------------------------------------------------------------------
    % Generate device Hamiltonian
    %----------------------------------------------------------------------

    [mat] = NEGF_H_construct(mat); % returns Hamiltonian of the device through Ham_0 and Ham_T matrices. 

    %----------------------------------------------------------------------
    % Change home folder and define output and input file names
    %----------------------------------------------------------------------

    d.LW_name = strcat('L',num2str(round(10^10*mat.NR_length)),'W',num2str(round(10^10*mat.NR_width))); %LW_name - device length and width naming
    d.out_folder_name = strcat(d.home_folder,mat.material_name,'_',d.LW_name,'/');
    [status, msg, msgID] = mkdir(d.out_folder_name);
    d.file_prefix = strcat(mat.material_name,'_',d.LW_name);
    d.input_file_name = strcat(d.out_folder_name, d.file_prefix,'.mat');

    all_names{i} = d.input_file_name;

    %----------------------------------------------------------------------
    % Set initial energy points
    %----------------------------------------------------------------------

    d.E = linspace(d.Emin,d.Emax,d.E_points);
    d.dE = diff(d.E); d.dE = [d.dE d.dE(length(d.dE))];
    
    %----------------------------------------------------------------------
    % Run NEGF simulations with Recursive Green's function (RGF)
    %----------------------------------------------------------------------

    fprintf(1,'Now running NEGF for all bands...\n')

    Np = mat.Nl;
    NU = mat.NU;

    [LDOS] = deal(zeros(length(d.E),Np)); % local density of states (LDOS)
    T = zeros(1,length(d.E)); % transmission cefficient
    Ia = eye(NU); % I matrix

    for simulation = 1 : 2
        if simulation == 1
            Esim = d.E;
        elseif simulation == 2
            Esim = d.E2;
        end

        NEGF_RGF % NEGF calculations using Recursive Green's function
        NEGF_TDOS_transform % DOS and T transformations

        %----------------------------------------------------------------------
        % Plot DOS and Transmission for simulated device
        %----------------------------------------------------------------------

        if simulation == 1
            figure, ...
                set(gcf,'position',[0,0,1000,400]);

            subplot(1,2,1);
            plot(d.E,d.T,'LineWidth',2);
            ylabel('Transmission', 'FontSize',12)
            xlabel('Energy, {\it E} (eV)','FontSize',12)
            xlim([d.Emin, d.Emax])

            subplot(1,2,2);
            plot(d.E,d.DOS/mat.NR_area);
            ylabel('Density of states (cm^{−2})', 'FontSize',12)
            xlabel('Energy, {\it E} (eV)','FontSize',12)
            xlim([d.Emin, d.Emax])
        end

    end
    fprintf(1,'NEGF DONE!\n');

    %----------------------------------------------------------------------
    % Save NEGF outputs needed for TOB simulations
    %----------------------------------------------------------------------

    save(d.input_file_name,'mat','d'); 
    
end

%--------------------------------------------------------------------------
% Save NEGF naming needed for TOB simulations
%--------------------------------------------------------------------------

Nw_all_sim = Nw_all;
out_save=strcat(d.home_folder,mat.material_name,'.mat');
if isfile(out_save)
    temp = all_names;
    load(out_save,'all_names',"Nw_all_sim")
    temp2 = [temp;all_names];
    all_names = cellstr(unique(vertcat(temp2{:})));
    Nw_all_sim = unique([Nw_all_sim Nw_all]);
end
save(out_save,'all_names',"Nw_all_sim")
