%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%         Parallel NEGF calculations using Recursive Green's functions
%         code within NEGF.m 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

parfor k = 1:length(Esim)

            fprintf(1,'...energy point = %d of %d.\n',k,length(Esim));
            
            [Ad, grL, Grd] = deal(zeros(NU,NU,Np));
            [Au,Al,Gru,Grl] = deal(zeros(NU,NU,Np-1));

            [sigma_l,sigma_r] = NEGF_SIGMA_sd_SR(mat,Esim(k),const.zplus);

            %---------------------------------------------------------------
            gamma_l = 1i*(sigma_l  - sigma_l');
            gamma_r  = 1i*(sigma_r - sigma_r');

            for j = 1: Np-1
                Ad(:,:,j) = (Esim(k) + const.zplus)*Ia - mat.Ham_0;
                Au(:,:,j) = mat.Ham_T;
                Al(:,:,j) = mat.Ham_T';
            end

            Ad(:,:,1) = (Esim(k) + const.zplus)*Ia -  mat.Ham_0 - sigma_l;
            Ad(:,:,Np) = (Esim(k) + const.zplus)*Ia -  mat.Ham_0 - sigma_r;

            %----------------------------------------------------
            grL(:,:,1) = inv(Ad(:,:,1));                              

            for j = 2 : Np                                          
                pom = (Ad(:,:,j) - Al(:,:,j-1)*grL(:,:,j-1)*Au(:,:,j-1));
                grL(:,:,j) = inv(pom);
            end

            Grd(:,:,Np) = grL(:,:,Np);                            

            for j = (Np-1):-1:1
                Grl(:,:,j) = -Grd(:,:,j+1)*Al(:,:,j)*grL(:,:,j);  
                Gru(:,:,j) = -grL(:,:,j)*Au(:,:,j)*Grd(:,:,j+1);  
                prom = Ia - Au(:,:,j)*Grl(:,:,j);
                Grd(:,:,j) = grL(:,:,j)*prom;                     
            end
            %----------------------------------------------------
            %LDOS calculation
            for j = 1 : Np
                % D0 = 1i*(Grd(:,:,j) - Grd(:,:,j)')/(2*pi);
                D0 = -2*imag(Grd(:,:,j))/(2*pi);
                LDOS(k,j) = 2*real(trace(D0));

            end

            %Transmission calculation

            GrT = Grd(:,:,Np);
            for j = Np-1 : -1 : 1
                GrT = -grL(:,:,j)*mat.Ham_T*GrT;
            end

            T(k) = real(trace(gamma_l*GrT*gamma_r*GrT'));
end