%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                       S/D sigma matrices calculation
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 
%   S/D contact self-energy matrices calculation using Sancho-Rubio method 
%   for calculation ideal contacts of the same material as the channel
%
%   Inputs:
%       - device Hamiltonian through Ham_0 and Ham_T matrices
%       - E, simulation energy range
%   Outputs:
%       - S/D sigma matrices 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [sigma_l,sigma_r] = NEGF_SIGMA_sd_SR(mat,E,zplus)

    A=mat.Ham_T; B=mat.Ham_T'; C=mat.Ham_0; D_l=mat.Ham_0;D_r=mat.Ham_0;

    errmax=1e-6; % Maximum error for Sancho-Rubio iteration
    err = 100; 

    while(err>errmax)

        Inv = ((E+zplus)*eye(mat.NU)-C)\eye(mat.NU);
        AIB = A*(Inv*B); BIA = B*(Inv*A);
        
        Anew = A * (Inv * A);
        Bnew = B * (Inv * B);
        Cnew = C + AIB + BIA;
        Dnew_l = D_l + BIA;
        Dnew_r = D_r + AIB;
        
        %Calculate errors and calculate maximum error
        err1 = max((abs(A-Anew)),[],'all'); err2 = max((abs(B-Bnew)),[],'all'); 
        err3 = max((abs(C-Cnew)),[],'all'); err4 = max((abs(D_l-Dnew_l)),[],'all');
        err5 = max((abs(D_r-Dnew_r)),[],'all');
        err=max([err1,err2,err3,err4,err5]);

        A=Anew; B=Bnew; C=Cnew; D_l=Dnew_l; D_r=Dnew_r;
    end
    
    gl=inv((E+zplus)*eye(mat.NU)-Dnew_l);
    gr=inv((E+zplus)*eye(mat.NU)-Dnew_r);

    sigma_l = mat.Ham_T'*gl*mat.Ham_T; % left contact
    sigma_r = mat.Ham_T*gr*mat.Ham_T'; % right contact
    
end

