%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%     TOB - find new self-consistent top of the barrier potential (Uscf)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%  

function [Qs_new,Usc_new,fE_s,fE_d] = tobiv_Usc_find(Usc0,Qs0,E,dE,DOS,Efs,errmax,t,Vg,Vd,Vs)
    
    constants;

    error=1; iter=0;
    Usc_new=Usc0;
    Usc_old=1e-3;
    Qs_new=0;
    Qs_old=1;
    
    while abs(error)>errmax && iter<10000

        iter=iter+1;

        error1 = abs(Qs_new-Qs_old)/abs(Qs_old);
        error2 = abs(Usc_new-Usc_old)/abs(Usc_old);
        error  = max(error1, error2);

        Qs_old = Qs_new;
        Usc_old=Usc_new;

        fE_s=1./(1+exp((E+Usc_new-(Efs+Vs))/const.kbT));
        Qs_s = 0.5 * sum(DOS.*fE_s)*dE; % 1/m2
        fE_d=1./(1+exp((E+Usc_new-(Efs-Vd))/const.kbT));
        Qs_d = 0.5 * sum(DOS.*fE_d)*dE; % 1/m2
        Qs_new=Qs_s+Qs_d-Qs0;

        Usc_new = Usc0 - t.alpha_g*Vg - t.alpha_d*Vd - t.alpha_s*Vs + const.q*Qs_new/(const.e0*t.epsil_r/t.tox);
        Usc_new = Usc_old + 0.1*(Usc_new-Usc_old);

    end

end