%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                               Save data
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

d.TOB_folder_name=strcat(d.out_folder_name,'TOB_',mat.material_name,'_',d.LW_name,'/');
[status, msg, msgID] = mkdir(d.TOB_folder_name);

d.TOB_file_name=strcat(d.TOB_folder_name,mat.material_name,'_',d.LW_name,'_');

inp_fname = erase(d.input_file_name,'.mat');
save(strcat(inp_fname,'_ToB.mat'),'mat','d');


% Write tranfer characteristics (Id - Vg)
filename = strcat(d.TOB_file_name,'iv_trans.txt');
names = {'Vg',strcat('ID(Vd_low=',num2str(t.Vdt_lo),'V)'),strcat('ID(Vd_high=',num2str(t.Vdt_hi),'V)')};
units = {'V','mA/um','mA/um'};
values = [Vgt(:) II_lo(:)*1e3 II_hi(:)*1e3];
formats = {'%f', '%E', '%E'};
writeFormattedText(filename, names, units, values, formats)


% Write output characteristics (Id - Vd)
filename = strcat(d.TOB_file_name,'iv_out.txt');
ID_cell = cell(1,NVg);
for i = 1 : NVg
    ID_cell(i) = {strcat('ID(Vg=',num2str(Vg(i)),'V)')};
end
names = [{'Vd'},ID_cell];
units = [{'V'},rep_cell(NVg,'A/um')];
values = [Vd(:) II(:,:)'];
formats = [{'%3.4f'}, rep_cell(NVg,'%12.10f')];
writeFormattedText(filename, names, units, values, formats)


% Charge density gate voltage dependance (Qs - Vg)
filename = strcat(d.TOB_file_name,'qs_vg.txt');
names = {'Vg','Qs'};
units = {'V','1/cm2'};
values = [Vgt(:) 1e-4*Qs_on(:)];
formats = {'%f', '%E'};
writeFormattedText(filename, names, units, values, formats)


% Injection velocity gate voltage dependance (Vinj - Vg)
filename = strcat(d.TOB_file_name,'vinj_vg.txt');
names = {'Vg','Vinj_on'};
units = {'V','cm/s'};
values = [Vgt(:) 1e2*Vel_on(:)];
formats = {'%f', '%E'};
writeFormattedText(filename, names, units, values, formats)


% Return cell of rep_value repeated rep_num times
function rep = rep_cell(rep_num, rep_value)
    rep = cell(1,rep_num); 
    rep(:) = {rep_value}; 
end
