%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                    TOB transfer characteristics
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
%
% input parameters defined in main_tob.m
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

if sim_IV == 1 
    t.Vgt_points_t = 3; 
else
   t.Vgt_points_t = t.Vgt_points; 
   fprintf(1,'Calculating transfer I-V characteristics!\n');
end

Vdt = [t.Vdt_lo,t.Vdt_hi]; NVd = length(Vdt);
Vgt = linspace(t.Vgt_min,t.Vgt_max,t.Vgt_points_t); NVgt = length(Vgt); 
Vst = t.Vst;

errmax=1e-6;

[II_lo, II_hi, Usc_all_Lo, Usc_all_Hi] = deal(zeros(1,NVgt));
[Qs_low, Vel_low] = deal(zeros(1,NVgt));
[Qs_on, Vel_on] = deal(zeros(1,NVgt));

fE_0 = 1./(1+exp((E-(Efs-Usc0))/const.kbT));
Qs0 = trapz(DOS.*fE_0)*dE;

NSD_source = t.frac*mat.Ndmax;

for hl = 1 : NVd
    dmu1 = 0.01e-3;

    for k=1:NVgt
        NSD_calc = 0;
        dmu1 = dmu1 - 0.01e-3;
        while NSD_calc < NSD_source
            Efs_new=Efs+dmu1;
            [Qs_new,Usc_new,fE_s,fE_d] = tobiv_Usc_find(Usc0,Qs0,E,dE,DOS,Efs_new,errmax,t,Vgt(k),Vdt(hl),Vst);
    
            NSD_calc = tobiv_NSD_floatingS(DOS,Usc_new,Efs_new,Vdt(hl),Vst,const,E,dE);
            dmu1 = dmu1 + 0.01e-3;
        end
         if Vdt(hl) == t.Vdt_lo
             Qs_low(k)=abs(Qs_new); % 1/m2
             II_lo(k) = 2 * const.q/const.h * sum(TRM0.*(fE_s-fE_d))*dE; % A/m
             Vel_low(k)= II_lo(k)/(NRWidth*1e-9)/(const.q*Qs_low(k)); %m/s

         elseif Vdt(hl) == t.Vdt_hi
             II_hi(k) = 2 * const.q/const.h * sum(TRM0.*(fE_s-fE_d))*dE; % A
             Qs_on(k) = abs(Qs_new); % 1/m2
             Vel_on(k)= II_hi(k)/(NRWidth*1e-9)/(const.q*Qs_on(k)); %m/s
             
         end
    end
end


II_lo=II_lo./(NRWidth*1e-3); % A/um
II_hi=II_hi./(NRWidth*1e-3); % A/um

I_on=max(II_hi);
I_off=min(II_hi);
IR=I_on/I_off;

if sim_IV == 2
    fprintf(1,'DONE with calculations of transfer I-V characteristics!\n\n');
end



