%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                       MAIN PROGRAM FOR NEGF SIMULATIONS
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 
%   NEGF calculations with:
%        - ideal contacts, i.e., source and drain self-energy matrices 
%          calculated using Sancho-Rubio method
%        - Recursive Green's function (RGF) used for calculation of 
%          transmission and DOS
%
%   Inputs defined in main:
%        - channel material 
%
%   Outputs:
%          - Density of states (DOS)
%          - Transmission (T)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% -------------------------------------------------------------------------
% Store needed parameters in mat and d data structures
% -------------------------------------------------------------------------
mat.FETtype = FET_type; mat.material_name = material_name; 
mat.version = version; mat.Lx_c = Lx_c; d.Lx_c = mat.Lx_c;

% -------------------------------------------------------------------------
% NEGF simulation parameters
% -------------------------------------------------------------------------

mat.NNeighbour = 1; % number of nearest neighbours taken into account (1,2,3)

% -------------------------------------------------------------------------
% First simulation
% Energy from d.Emin to d.Emax at d.E_points number of energy points with middle of
% the bandgap set to 0 eV
% -------------------------------------------------------------------------

d.E_points = 1000;

d.Emin = -2.5;
d.Emax = 2.5;

% -------------------------------------------------------------------------
% Second simulation for NFET or PFET 
% CBM/VBM set at 0 eV in second NEGF simulation
% Energy from d.E2_min to d.E2_max at d.E2_points number of energy points with CBM/VBM set to 0 eV
% -------------------------------------------------------------------------

d.E2_points = 4001; 

if mat.FETtype == 'N' % CBM at 0 eV
    d.E2_min = -0.2;  
    d.E2_max =  0.8;  
elseif mat.FETtype == 'P' % VBM at 0 eV
    d.E2_min = -0.8;
    d.E2_max =  0.2;
end

% -------------------------------------------------------------------------
% Run NEGF script
% -------------------------------------------------------------------------

NEGF

% -------------------------------------------------------------------------