%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                       MAIN PROGRAM FOR TOB SIMULATIONS
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Top-of-the-Barrier (TOB) model is used for simulation of single gate FET
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% -------------------------------------------------------------------------
% Store needed parameters in t data structure
% -------------------------------------------------------------------------
t.epsil_r = epsil_r; t.tox = tox; t.frac = frac;

% -------------------------------------------------------------------------
% TOB simulation parameters
% Device control parameters (drain induced barrier lowering (DIBL) and subthreshold slope (SS))
% -------------------------------------------------------------------------

DIBL = 0; % set DIBL (mV/V)
% SS = 85; % subthreshold slope (mV/dek)
% t.alpha_g=log(10)*const.kbT*1000/SS

t.alpha_g=0.99; % gate control
t.alpha_d=0.01; % drain control
t.alpha_s=0;    % source control

% -------------------------------------------------------------------------
% Setting the OFF state current (Ioff) setting
% -------------------------------------------------------------------------

t.I_off_set=10*1e-9; % Ioff set (A/um)

t.I_off_set_switch = 'T'; %'T' to set the Ioff, 'F' to not set the Ioff

% -------------------------------------------------------------------------
% TOB Transfer characteristics input parameters
% 
% Transfer characteristics are plotted for low drain voltage (t.Vdt_lo) and
% high drain voltage (t.Vdt_hi)
% Gate voltage range is defined with t.Vgt_min and t.Vgt_max while number
% of points in given range is defined with t.Vgt_points
%
% Source voltage t.Vst;
% -------------------------------------------------------------------------

t.Vdt_lo=0.05; 
t.Vdt_hi=0.7;

t.Vgt_min = 0;
t.Vgt_max = 0.7;
t.Vgt_points = 21;

t.Vst = 0;

% -------------------------------------------------------------------------
% TOB Output characteristics input parameters
% 
% Output characteristics are plotted for voltage range from t.Vdo_min to t.Vdo_max 
% while number of points in given range is defined with t.Vdo_points
%
% Gate voltage range is defined with t.Vgo_min and t.Vgo_max while number
% of points in given range is defined with t.Vgo_points
%
% Source voltage t.Vso;
% -------------------------------------------------------------------------

t.Vgo_min = 0;
t.Vgo_max = 0.7;
t.Vgo_points = 8; 

t.Vdo_min = 0;
t.Vdo_max = 0.7;
t.Vdo_points = 11; 

t.Vso = 0;

% -------------------------------------------------------------------------
% Run TOB for all devices for which NEGF simulations were made
% -------------------------------------------------------------------------

load(strcat(d.home_folder,mat.material_name,'.mat'),'all_names',"Nw_all_sim")
for i = 1 : length(Nw_all)    
    if ismember(Nw_all(i),Nw_all_sim)
        tobiv(t,Nw_all(i),all_names{find(Nw_all_sim == Nw_all(i))});
    end
end

% -------------------------------------------------------------------------
